@@ -29,6 +29,9 @@ SERVICE_VERSIONS = {
     "afc": [
         "2020-02-26"
     ],
+    "aiart": [
+        "2022-12-29"
+    ],
     "ame": [
         "2019-09-16"
     ],
